# -*- coding: cp1252 -*-
#
##################################################################################
#
#    Copyright 2016 Félix Brezo and Yaiza Rubio (i3visio, contacto@i3visio.com)
#
#    This file is part of OSRFramework. You can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##################################################################################

import torfy

WELCOME_TEXT = """
 _____           __       
|_   _|__  _ __ / _|_   _           What's this?  
  | |/ _ \| '__| |_| | | |          ------------
  | | (_) | |  |  _| |_| |          
  |_|\___/|_|  |_|  \__, |          This script is part of Torfy, a GPLv3+
                    |___/           library to deal with Tor connections.

                Version:      Torfy """ + torfy.__version__ + """
                Created by:   Felix Brezo and Yaiza Rubio, (i3visio)

"""

